package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsIndustrialInternetAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsIndustrialInternetAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsIndustrialInternetAwardUpdateDto;
import com.ruoyi.jjh.declaration.mapper.BmsIndustrialInternetAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsIndustrialInternetAwardService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 5G+工业互联网奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsIndustrialInternetAwardServiceImpl extends ServiceImpl<BmsIndustrialInternetAwardMapper,BmsIndustrialInternetAward> implements IBmsIndustrialInternetAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    /**
     * 查询5G+工业互联网奖补
     * 
     * @param id 5G+工业互联网奖补主键
     * @return 5G+工业互联网奖补
     */
    @Override
    public BmsIndustrialInternetAward selectBmsIndustrialInternetAwardById(Long id) {
        return baseMapper.selectBmsIndustrialInternetAwardById(id);
    }

    /**
     * 查询5G+工业互联网奖补列表
     * 
     * @param bmsIndustrialInternetAward 5G+工业互联网奖补
     * @return 5G+工业互联网奖补
     */
    @Override
    public List<BmsIndustrialInternetAward> selectBmsIndustrialInternetAwardList(BmsIndustrialInternetAward bmsIndustrialInternetAward) {
        return baseMapper.selectBmsIndustrialInternetAwardList(bmsIndustrialInternetAward);
    }

    /**
     * 新增5G+工业互联网奖补
     * 
     * @param bmsIndustrialInternetAwardAddDto 5G+工业互联网奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsIndustrialInternetAward(BmsIndustrialInternetAwardAddDto bmsIndustrialInternetAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsIndustrialInternetAwardAddDto.getCreditCode()
                ,bmsIndustrialInternetAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsIndustrialInternetAwardAddDto.getCreditCode()
                ,bmsIndustrialInternetAwardAddDto.getTemplateRecordId());
        BmsIndustrialInternetAward bmsIndustrialInternetAward = new BmsIndustrialInternetAward();
        BeanUtil.copyProperties(bmsIndustrialInternetAwardAddDto,bmsIndustrialInternetAward);
        bmsIndustrialInternetAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsIndustrialInternetAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        BeanUtil.copyProperties(bmsIndustrialInternetAwardAddDto,declarationRecords);
        declarationRecords.setMatter("提交5G+工业互联网奖补申请");
        declarationRecords.setEnterpriseId(enterpriseId);
        declarationRecords.setDetailId(bmsIndustrialInternetAward.getId());
        iBmsDeclarationRecordsService.save(declarationRecords);
        // 生成审核
        if (bmsIndustrialInternetAwardAddDto.getStatus()==1){
            // 审批状态
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改5G+工业互联网奖补
     * 
     * @param bmsIndustrialInternetAwardUpdateDto 5G+工业互联网奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsIndustrialInternetAward(BmsIndustrialInternetAwardUpdateDto bmsIndustrialInternetAwardUpdateDto) {
        int num = 0;
        try {
            iBmsDeclarationRecordsService.updateDeclarationRecords(bmsIndustrialInternetAwardUpdateDto.getDeclarationRecordsId()
                    ,bmsIndustrialInternetAwardUpdateDto.getProjectId(),bmsIndustrialInternetAwardUpdateDto.getProjectName()
                    ,bmsIndustrialInternetAwardUpdateDto.getStatus());

            bmsIndustrialInternetAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsIndustrialInternetAward(bmsIndustrialInternetAwardUpdateDto);
            // 申请审批
            if (bmsIndustrialInternetAwardUpdateDto.getStatus()==1){
                // 审批状态
                iCommonService.insertAuditRecord(bmsIndustrialInternetAwardUpdateDto.getDeclarationRecordsId(),0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除5G+工业互联网奖补
     * 
     * @param ids 需要删除的5G+工业互联网奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIndustrialInternetAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsIndustrialInternetAwardByIds(ids);
    }

    /**
     * 删除5G+工业互联网奖补信息
     * 
     * @param id 5G+工业互联网奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIndustrialInternetAwardById(Long id) {
        return baseMapper.deleteBmsIndustrialInternetAwardById(id);
    }
}
